@@ -8,10 +8,17 @@
 void Cigamx2d(int ConTxt, char *scope, char *top, int m, int n, int *A,
               int lda, int *rA, int *cA, int ldia, int rdest, int cdest)
 #else
+#ifdef FC_LEN_T
+F_VOID_FUNC igamx2d_(int *ConTxt, F_CHAR scope, F_CHAR top, int *m, int *n,
+                     int *A, int *lda, int *rA, int *cA, int *ldia,
+                     int *rdest, int *cdest,
+                     FC_LEN_T scope_len, FC_LEN_T top_len)
+#else
 F_VOID_FUNC igamx2d_(int *ConTxt, F_CHAR scope, F_CHAR top, int *m, int *n,
                      int *A, int *lda, int *rA, int *cA, int *ldia,
                      int *rdest, int *cdest)
 #endif
+#endif
 /*
  *  -- V1.1 BLACS routine --
  *  University of Tennessee, May 1, 1996
@@ -200,7 +207,8 @@ F_VOID_FUNC igamx2d_(int *ConTxt, F_CHAR scope, F_CHAR top, int *m, int *n,
       bp = BI_GetBuff(i);
       bp2 = &BI_AuxBuff;
       bp2->Buff = &bp->Buff[length];
-      BI_imvcopy(Mpval(m), Mpval(n), A, tlda, bp->Buff);
+      /*WCC BI_imvcopy(Mpval(m), Mpval(n), A, tlda, bp->Buff); */
+      BI_imvcopy(Mpval(m), Mpval(n), A, tlda, (int*) bp->Buff);
 /*
  *    Fill in distance vector
  */
@@ -258,7 +266,8 @@ F_VOID_FUNC igamx2d_(int *ConTxt, F_CHAR scope, F_CHAR top, int *m, int *n,
          bp = BI_GetBuff(length*2);
          bp2 = &BI_AuxBuff;
          bp2->Buff = &bp->Buff[length];
-         BI_imvcopy(Mpval(m), Mpval(n), A, tlda, bp->Buff);
+         /*WCC BI_imvcopy(Mpval(m), Mpval(n), A, tlda, bp->Buff); */
+         BI_imvcopy(Mpval(m), Mpval(n), A, tlda, (int*) bp->Buff);
       }
       bp->N = bp2->N = N;
       bp->dtype = bp2->dtype = MPI_INT;
@@ -270,14 +279,12 @@ F_VOID_FUNC igamx2d_(int *ConTxt, F_CHAR scope, F_CHAR top, int *m, int *n,
       i = 1;
       if (Mpval(ldia) == -1)
       {
-         //WCC ierr=MPI_Op_create(BI_iMPI_amx2, i, &BlacComb);
-         //WCC:add
+         /*WCC ierr=MPI_Op_create(BI_iMPI_amx2, i, &BlacComb); */
          ierr=MPI_Op_create((MPI_User_function *) BI_iMPI_amx2, i, &BlacComb);
       }
       else
       {
-         //WCC ierr=MPI_Op_create(BI_iMPI_amx, i, &BlacComb);
-         //WCC:add
+         /*WCC ierr=MPI_Op_create(BI_iMPI_amx, i, &BlacComb); */
          ierr=MPI_Op_create((MPI_User_function *) BI_iMPI_amx, i, &BlacComb);
          BI_AuxBuff.Len = N;  /* set this up for the MPI OP wrappers */
       }
@@ -288,7 +295,8 @@ F_VOID_FUNC igamx2d_(int *ConTxt, F_CHAR scope, F_CHAR top, int *m, int *n,
 	 	       ctxt->scp->comm);
          if (ctxt->scp->Iam == dest)
 	 {
-	    BI_ivmcopy(Mpval(m), Mpval(n), A, tlda, bp2->Buff);
+	    /*WCC BI_ivmcopy(Mpval(m), Mpval(n), A, tlda, bp2->Buff); */
+	    BI_ivmcopy(Mpval(m), Mpval(n), A, tlda, (int*) bp2->Buff);
 	    if (Mpval(ldia) != -1)
                BI_TransDist(ctxt, tscope, Mpval(m), Mpval(n), rA, cA, tldia,
                             (BI_DistType *) &bp2->Buff[idist],
@@ -299,7 +307,8 @@ F_VOID_FUNC igamx2d_(int *ConTxt, F_CHAR scope, F_CHAR top, int *m, int *n,
       {
          ierr=MPI_Allreduce(bp->Buff, bp2->Buff, bp->N, bp->dtype, BlacComb,
 		          ctxt->scp->comm);
-	 BI_ivmcopy(Mpval(m), Mpval(n), A, tlda, bp2->Buff);
+	 /*WCC BI_ivmcopy(Mpval(m), Mpval(n), A, tlda, bp2->Buff); */
+	 BI_ivmcopy(Mpval(m), Mpval(n), A, tlda, (int*) bp2->Buff);
          if (Mpval(ldia) != -1)
             BI_TransDist(ctxt, tscope, Mpval(m), Mpval(n), rA, cA, tldia,
                          (BI_DistType *) &bp2->Buff[idist],
@@ -378,6 +387,7 @@ F_VOID_FUNC igamx2d_(int *ConTxt, F_CHAR scope, F_CHAR top, int *m, int *n,
 /*
  *    Unpack the amx array
  */
-      if (bp != &BI_AuxBuff) BI_ivmcopy(Mpval(m), Mpval(n), A, tlda, bp->Buff);
+      /*WCC if (bp != &BI_AuxBuff) BI_ivmcopy(Mpval(m), Mpval(n), A, tlda, bp->Buff); */
+      if (bp != &BI_AuxBuff) BI_ivmcopy(Mpval(m), Mpval(n), A, tlda, (int*) bp->Buff);
    }
 }
